pub enum ActiveRefMetadata {
Missing,
Valid(String),
Invalid(String),
}Expand description
Active-WAL ref metadata read result.
Variants
Missing
Metadata file is absent.
Valid(String)
Metadata file contains a valid canonical local branch ref.
Invalid(String)
Metadata file exists but is malformed or not a valid local branch ref.