pub enum WorktreeChangeKind {
Missing,
Modified,
Untracked,
UnsupportedPath,
}Expand description
Worktree change kind.
Variants
Missing
A tracked snapshot file is missing from the worktree.
Modified
A tracked snapshot file exists but differs from the baseline bytes.
Untracked
A worktree file is not present in the snapshot baseline.
UnsupportedPath
A worktree path could not be safely represented as a Prikk repo path.
Implementations