pub enum WorktreePatchOperationKind {
CreateFile,
DeleteFile,
ReplaceBinary,
EditText,
ChangePerm,
}Expand description
Generated operation kind for CLI/reporting.
Variants
CreateFile
A new file will be represented as CreateFile.
DeleteFile
A missing tracked file will be represented as DeleteFile.
ReplaceBinary
A modified tracked file will be represented as ReplaceBinary.
EditText
A modified UTF-8 text file is represented as an arbitrary-span EditText.
ChangePerm
A regular file whose normalized mode changed is represented as ChangePerm.
Implementations