pub struct ActiveWalOrderingIssue {
pub index: usize,
pub previous_seq: u64,
pub seq: u64,
}Expand description
One active-WAL record whose sequence did not strictly increase over the previous record.
Fields
index: usizeZero-based position of the offending record within the replayed WAL.
previous_seq: u64Sequence of the previous record.
seq: u64Sequence of the offending record (not greater than previous_seq).