pub struct CheckoutPlan {
pub ref_name: String,
pub ref_state_id: Option<ObjectId>,
pub block_id: Option<ObjectId>,
pub block_kind: Option<BlockKind>,
pub parent_count: usize,
pub patch_count: usize,
pub snapshot_blob_ref: Option<ObjectId>,
pub materialization: CheckoutMaterialization,
}Expand description
Read-only plan for a future checkout/materialization operation.
Fields
ref_name: StringHuman-readable ref name.
ref_state_id: Option<ObjectId>Current RefState ID, if the ref is published.
block_id: Option<ObjectId>Target block ID, if the ref is published.
block_kind: Option<BlockKind>Target block kind, if the target block exists and decodes.
parent_count: usizeNumber of parent blocks referenced by the target block.
patch_count: usizeNumber of patches referenced by the target block.
snapshot_blob_ref: Option<ObjectId>Optional snapshot blob reference from the target block.
materialization: CheckoutMaterializationMaterialization status for this implementation stage.
Implementations
Sourceimpl CheckoutPlan
impl CheckoutPlan
Sourcepub const fn has_target_block(&self) -> bool
pub const fn has_target_block(&self) -> bool
Return true when the plan has a published target block.