FileObjectStore

Struct FileObjectStore 

pub struct FileObjectStore { /* private fields */ }
File-backed object store.

Implementations

Source

impl FileObjectStore

pub fn new(layout: RepositoryLayout) -> Self

Create a file object store for a repository layout.

pub fn layout(&self) -> &RepositoryLayout

Return the repository layout.

pub fn contains_object(&self, object_type: ObjectType, id: ObjectId) -> bool

Return true if an object with this id and type is indexed.