MergeEvidenceDisplay

Struct MergeEvidenceDisplay 

pub struct MergeEvidenceDisplay {
    pub baseline_block_id: ObjectId,
    pub left_selector: MergeEvidenceDisplaySelector,
    pub right_selector: MergeEvidenceDisplaySelector,
    pub outcome: &'static str,
    pub reason: Option<&'static str>,
    pub left_operation_count: usize,
    pub right_operation_count: usize,
    pub items: Vec<MergeEvidenceDisplayItem>,
}
Public display view for read-only merge/conflict evidence.

Fields

baseline_block_id: ObjectId

Explicit sealed baseline block.

left_selector: MergeEvidenceDisplaySelector

Submitted left selector plus resolved target block.

right_selector: MergeEvidenceDisplaySelector

Submitted right selector plus resolved target block.

outcome: &'static str

DC-21 outcome name.

reason: Option<&'static str>

Primary reason code, if the report produced an item.

left_operation_count: usize

Left sequence operation count.

right_operation_count: usize

Right sequence operation count.

items: Vec<MergeEvidenceDisplayItem>

Deterministic display items.

Implementations

Source

impl MergeEvidenceDisplay

pub fn displayed_item_count(&self) -> usize

Number of report items displayed by this view.

pub fn total_item_count(&self) -> usize

Number of report items in the full evidence report.