RollbackDraftVerification

Struct RollbackDraftVerification 

pub struct RollbackDraftVerification {
    pub ref_name: String,
    pub wal_sequence: u64,
    pub draft_patch_id: ObjectId,
    pub author_key_id: String,
    pub target_block_id: ObjectId,
    pub block_count: usize,
    pub patch_count: usize,
    pub inverse_operation_count: usize,
    pub decoded_operation_count: usize,
}
Verification result for one active rollback draft.

Fields

ref_name: String

Ref used to derive the expected inverse Patch.

wal_sequence: u64

WAL sequence containing the rollback draft Patch envelope.

draft_patch_id: ObjectId

Signed rollback draft Patch ID currently present in the active WAL.

author_key_id: String

Real AUTHOR key id recorded in the rollback draft signature.

target_block_id: ObjectId

Published block that was used as the rollback target.

block_count: usize

Number of blocks inspected while deriving the expected inverse.

patch_count: usize

Number of patch objects inspected while deriving the expected inverse.

inverse_operation_count: usize

Number of supported inverse operations expected for this rollback draft.

decoded_operation_count: usize

Number of supported operations decoded from the active WAL payload.