WorktreeStatusReport

Struct WorktreeStatusReport 

pub struct WorktreeStatusReport {
    pub ref_name: String,
    pub tracked_files: usize,
    pub unchanged_files: usize,
    pub changes: Vec<WorktreeChange>,
}
Read-only worktree status report against a snapshot baseline.

Fields

ref_name: String

Human-readable ref name used as the baseline.

tracked_files: usize

Number of tracked files in the snapshot baseline.

unchanged_files: usize

Number of tracked files that match the baseline bytes.

changes: Vec<WorktreeChange>

Worktree changes detected against the baseline.

Implementations

Source

impl WorktreeStatusReport

pub fn is_clean(&self) -> bool

Return true when the worktree has no detected changes.

pub fn count_kind(&self, kind: WorktreeChangeKind) -> usize

Count changes by kind.