pub struct FileObjectStore { /* private fields */ }Expand description
File-backed object store.
Implementations
Sourceimpl FileObjectStore
impl FileObjectStore
Sourcepub fn new(layout: RepositoryLayout) -> Self
pub fn new(layout: RepositoryLayout) -> Self
Create a file object store for a repository layout.
Sourcepub fn layout(&self) -> &RepositoryLayout
pub fn layout(&self) -> &RepositoryLayout
Return the repository layout.
Sourcepub fn contains_object(&self, object_type: ObjectType, id: ObjectId) -> bool
pub fn contains_object(&self, object_type: ObjectType, id: ObjectId) -> bool
Return true if an object with this id and type is indexed.